<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Kliknite ikonu trake
ili pritisnite ponovno prečac za prekid snimanja</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Nemožete okrenuti zaslon tijekom snimanja</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Slika zaslona</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Snimanje</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Snimi</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Slika zaslona</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Snimanje zaslona</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Neuspjelo spremanje. Molim spremite u vašoj osobnoj mapi.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Slika zaslona završena</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>odaberi-područje</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Spremljeno u %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Zanemari</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Oglasnik</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Spremanje datoteke snimanja zaslona, molimo pričekajte...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Kako je učinak prozora onemogućen tijekom procesa, snimanje mora biti zaustavljeno</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Slika zaslona</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Snimanje zaslona nije uspješno.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fiksirajte snimke</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Otvori mapa</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Snimanje zaslona završeno i kopirano u oglasnik</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Povuči</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izađi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fiksirajte snimke</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Snimanje zaslona</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Snimi</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Snimanje zaslona</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Snimanje</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Snimanje završeno</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Spremljeno u %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Snimi</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Otvori mapa</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Snimanje zaslona će početi za %1 sekundi</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Pronađite pomoć.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Nije moguće uzeti kontinuirano snimanje zaslona.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Dolazite do dna područja za scroll</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Dostigli ste maksimalnu duljinu</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>prilagodite područje snimanja</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Scrollajte točku miša ili kliknite za uzimanje scroll snimke</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Spustite brzinu scrollanja</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Nevažeće područje, kliknite za </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Unesite tekst ovdje</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Početak/slika zaslona</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Izađi/spremi</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Prilagodba veličine</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Brzi početak</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Snimka zaslona prozora</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Odgodi snimku zaslona</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Cijela snimka zaslona</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izađi</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Pravokutnik</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Crta</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Olovka</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Povuči</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Povećajte visinu gore</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Povećajte visinu dolje</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Povećajte dužinu lijevo</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Povećajte dužinu desno</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Smanjite visinu gore</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Smanjite visinu dolje</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Smanjite dužinu lijevo</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Smanjite dužinu desno</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži prečace</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Клање</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Započni snimanje</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Početak/snimanje</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Miš</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Alati</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Izvuci tekst</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Zakači snimke zaslona</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Počni OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Počni scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Strijela</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Slika zaslona</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Zapis</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Pravokutnik
Pritisnite i držite Shift za crtanje kvadrata</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elipsa
Pritisnite i držite Shift za crtanje kruga</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pena
Pritisnite i držite Shift za crtanje prave linije</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Prilagodite jačinu zagađenja (Povucite za prilagodbu)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Prilagodite veličinu pene (Povucite za prilagodbu)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Prilagodite veličinu teksta (Povucite za prilagodbu)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Klikni ili privuci za
odabir područja snimanja</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Pokaži klasifikaciju (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Sakrij klasifikaciju (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Pokaži klasifikaciju (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Uključi kameru (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Isključi kameru (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Slika zaslona</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Postavke (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Sistemski zvuk</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Pokaži pokazivač</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Pokaži klik</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Spremi u</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Radna površina</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>Pravokutnik (R)
Pritisnite i držite Shift za crtanje kvadrata</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>Elipsa (O)
Pritisnite i držite Shift za crtanje kruga</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Linija (L)
Pritisnite i držite Shift za crtanje vertikalne ili horizontalne linije</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Spuštanje (X)
Pritisnite i držite Shift za crtanje vertikalne ili horizontalne seme</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Olovka (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Pamutnica (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Tekst (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Scrollshot (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Izvlači tekst (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Zaključaj snimke (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Povuči (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Snimi</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Oštećenje</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Postavi put na spremanje</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Promijeni put na spremanje</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efekti ruba</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nijedan</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Sjenka</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Rub</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Uređaj</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Izvlači tekst</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Zatvori (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Prilagodi područje snimanja unutar %1*%2 za bolji vide efekt</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Snimanje zaslona nije trenutno podržano</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izađi</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Nova snimanja</translation>
    </message>
</context>
</TS>
